@@ -43,18 +43,21 @@
 #include <gconf/gconf-client.h>
 
 #include "burn-basics.h"
-#include "brasero-track.h"
-#include "brasero-medium.h"
-#include "brasero-session.h"
-#include "brasero-drive.h"
-#include "brasero-volume.h"
-#include "brasero-burn-lib.h"
 #include "burn-plugin-manager.h"
 #include "brasero-medium-selection-priv.h"
+#include "brasero-session-helper.h"
 
 #include "brasero-dest-selection.h"
+
+#include "brasero-drive.h"
+#include "brasero-medium.h"
+#include "brasero-volume.h"
+
+#include "brasero-burn-lib.h"
+#include "brasero-tags.h"
+#include "brasero-track.h"
+#include "brasero-session.h"
 #include "brasero-session-cfg.h"
-#include "brasero-session-helper.h"
 
 typedef struct _BraseroDestSelectionPrivate BraseroDestSelectionPrivate;
 struct _BraseroDestSelectionPrivate
@@ -223,6 +226,7 @@ brasero_dest_selection_clean (BraseroDestSelection *self)
 	if (priv->locked_drive) {
 		brasero_drive_unlock (priv->locked_drive);
 		g_object_unref (priv->locked_drive);
+		priv->locked_drive = NULL;
 	}
 }
 
@@ -234,7 +238,8 @@ brasero_dest_selection_finalize (GObject *object)
 }
 
 static goffset
-_get_medium_free_space (BraseroMedium *medium)
+_get_medium_free_space (BraseroMedium *medium,
+                        goffset session_blocks)
 {
 	BraseroMedia media;
 	goffset blocks = 0;
@@ -243,15 +248,15 @@ _get_medium_free_space (BraseroMedium *medium)
 	media = brasero_burn_library_get_media_capabilities (media);
 
 	/* NOTE: we always try to blank a medium when we can */
-	if (media & BRASERO_MEDIUM_REWRITABLE)
-		brasero_medium_get_free_space (medium,
-					       NULL,
-					       &blocks);
-	else {
-		brasero_medium_get_free_space (medium,
-					       NULL,
-					       &blocks);
-	}
+	brasero_medium_get_free_space (medium,
+				       NULL,
+				       &blocks);
+
+	if ((media & BRASERO_MEDIUM_REWRITABLE)
+	&& blocks < session_blocks)
+		brasero_medium_get_capacity (medium,
+		                             NULL,
+		                             &blocks);
 
 	return blocks;
 }
@@ -316,12 +321,12 @@ brasero_dest_selection_foreach_medium (BraseroMedium *medium,
 choose_closest_size:
 
 	brasero_burn_session_get_size (session, &session_blocks, NULL);
-	medium_blocks = _get_medium_free_space (medium);
+	medium_blocks = _get_medium_free_space (medium, session_blocks);
 
 	if (medium_blocks - session_blocks <= 0)
 		return TRUE;
 
-	burner_blocks = _get_medium_free_space (brasero_drive_get_medium (burner));
+	burner_blocks = _get_medium_free_space (brasero_drive_get_medium (burner), session_blocks);
 	if (burner_blocks - session_blocks <= 0)
 		brasero_burn_session_set_burner (session, brasero_medium_get_drive (medium));
 	else if (burner_blocks - session_blocks > medium_blocks - session_blocks)
@@ -499,6 +504,29 @@ brasero_dest_selection_format_medium_string (BraseroMediumSelection *selection,
 	if (brasero_medium_get_status (medium) & BRASERO_MEDIUM_FILE) {
 		gchar *path;
 
+		input = brasero_track_type_new ();
+		brasero_burn_session_get_input_type (priv->session, input);
+
+		/* There should be a special name for image in video context */
+		if (brasero_track_type_get_has_stream (input)
+		&&  BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (input))) {
+			BraseroImageFormat format;
+
+			format = brasero_burn_session_get_output_format (priv->session);
+			if (format == BRASERO_IMAGE_FORMAT_CUE) {
+				g_free (medium_name);
+				if (brasero_burn_session_tag_lookup_int (priv->session, BRASERO_VCD_TYPE) == BRASERO_SVCD)
+					medium_name = g_strdup (_("SVCD image"));
+				else
+					medium_name = g_strdup (_("VCD image"));
+			}
+			else if (format == BRASERO_IMAGE_FORMAT_BIN) {
+				g_free (medium_name);
+				medium_name = g_strdup (_("Video DVD image"));
+			}
+		}
+		brasero_track_type_free (input);
+
 		/* get the set path for the image file */
 		path = brasero_dest_selection_get_output_path (BRASERO_DEST_SELECTION (selection));
 		if (!path)
@@ -554,25 +582,12 @@ brasero_dest_selection_format_medium_string (BraseroMediumSelection *selection,
 				       &data_blocks,
 				       &session_bytes);
 
-	if (flags & (BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_APPEND)) {
-		brasero_medium_get_free_space (medium,
-					       &size_bytes,
-					       &blocks);
-	}
-	else {
+	if (flags & (BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_APPEND))
+		brasero_medium_get_free_space (medium, &size_bytes, &blocks);
+	else if (brasero_burn_library_get_media_capabilities (media) & BRASERO_MEDIUM_REWRITABLE)
+		brasero_medium_get_capacity (medium, &size_bytes, &blocks);
+	else
 		brasero_medium_get_free_space (medium, &size_bytes, &blocks);
-
-		/* if data would not fit, try to see if once blanked it would
-		 * work. This also covers the case where the media is closed as
-		 * its free space would be 0. This is the best way to do it
-		 * instead of checking for a CLOSED medium as it allows the 
-		 * overwrite media to be appended or merged if need be. */
-		if ((!blocks || blocks > data_blocks)
-		&& (brasero_burn_library_get_media_capabilities (media) & BRASERO_MEDIUM_REWRITABLE))
-			brasero_medium_get_capacity (medium,
-						     &size_bytes,
-						     &blocks);
-	}
 
 	if (blocks) {
 		used = data_blocks * 100 / blocks;
@@ -599,6 +614,18 @@ brasero_dest_selection_format_medium_string (BraseroMediumSelection *selection,
 
 	/* format the size */
 	if (brasero_track_type_get_has_stream (input)
+	&& BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (input))) {
+		guint64 free_time;
+
+		/* This is an embarassing problem: this is an approximation
+		 * based on the fact that 2 hours = 4.3GiB */
+		free_time = size_bytes - session_bytes;
+		free_time = free_time * 72000LL / 47LL;
+		size_string = brasero_units_get_time_string (free_time,
+							     TRUE,
+							     TRUE);
+	}
+	else if (brasero_track_type_get_has_stream (input)
 	|| (brasero_track_type_get_has_medium (input)
 	&& (brasero_track_type_get_medium_type (input) & BRASERO_MEDIUM_HAS_AUDIO)))
 		size_string = brasero_units_get_time_string (BRASERO_BYTES_TO_DURATION (size_bytes - session_bytes),
