@@ -99,6 +99,7 @@ brasero_libisofs_thread_finished (gpointer data)
 	if (brasero_job_get_fd_out (BRASERO_JOB (self), NULL) != BRASERO_BURN_OK) {
 		BraseroTrackImage *track = NULL;
 		gchar *output = NULL;
+		goffset blocks = 0;
 
 		/* Let's make a track */
 		track = brasero_track_image_new ();
@@ -110,6 +111,9 @@ brasero_libisofs_thread_finished (gpointer data)
 						NULL,
 						BRASERO_IMAGE_FORMAT_BIN);
 
+		brasero_job_get_session_output_size (BRASERO_JOB (self), &blocks, NULL);
+		brasero_track_image_set_block_num (track, blocks);
+
 		brasero_job_add_track (BRASERO_JOB (self), BRASERO_TRACK (track));
 
 		/* It's good practice to unref the track afterwards as we don't
@@ -136,7 +140,7 @@ brasero_libisofs_write_sector_to_fd (BraseroLibisofs *self,
 		gint written;
 
 		written = write (fd,
-				 buffer + bytes_written,
+				 ((gchar *) buffer) + bytes_written,
 				 bytes_remaining);
 
 		if (priv->cancel)
@@ -178,6 +182,8 @@ brasero_libisofs_write_image_to_fd_thread (BraseroLibisofs *self)
 
 	priv = BRASERO_LIBISOFS_PRIVATE (self);
 
+	brasero_job_set_nonblocking (BRASERO_JOB (self), NULL);
+
 	brasero_job_set_current_action (BRASERO_JOB (self),
 					BRASERO_BURN_ACTION_CREATING_IMAGE,
 					NULL,
